/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.modger.formatter.message;

import biz.massivedynamics.modger.formatter.Formatter;
import biz.massivedynamics.modger.message.Message;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * A multiple line message formatter
 *
 * @author Cruz Bishop
 * @since 1.0.0.0
 */
public class MultipleLineMessageFormatter extends Formatter<Message, Message> {
    
    /**
     * The date format
     * 
     * @since 1.0.0.0
     */
    private SimpleDateFormat dateFormat = new SimpleDateFormat("d MMM yyyy hh:mm:ss a");

    /**
     * Formats the message
     * 
     * @param message The message to format
     * @return The formatted message
     * @since 1.0.0.0
     */
    @Override
    public Message format(Message message) {
        
        //Clone the message
        Message newMessage = message.clone();
        
        //Set the message
        newMessage.setMessage(dateFormat.format(new Date()) 
                + " - [" + message.getType().name() + "] " 
                + message.getLogger().getName() + ":\r\n \t" 
                + message.getMessage());
        
        //Return the message
        return newMessage;
        
    }
    
}
